EXPORTS
	CreateLogicalDevice__Fv @ 1 NONAME ; CreateLogicalDevice(void)
	__12DMediaDriveri @ 2 NONAME ; DMediaDriver::DMediaDriver(int)
	Close__12DMediaDriver @ 3 NONAME ; DMediaDriver::Close(void)
	Complete__12DMediaDriverR14TLocDrvRequesti @ 4 NONAME ; DMediaDriver::Complete(TLocDrvRequest &, int)
	Connect__17DPrimaryMediaBaseP11DLocalDrive @ 5 NONAME ; DPrimaryMediaBase::Connect(DLocalDrive *)
	Create__17DPrimaryMediaBase12TMediaDeviceii @ 6 NONAME ; DPrimaryMediaBase::Create(TMediaDevice, int, int)
	DeltaCurrentConsumption__17DPrimaryMediaBasei @ 7 NONAME ; DPrimaryMediaBase::DeltaCurrentConsumption(int)
	Disconnect__17DPrimaryMediaBaseP11DLocalDrive @ 8 NONAME ; DPrimaryMediaBase::Disconnect(DLocalDrive *)
	DoEndInCritical__17DPrimaryMediaBase @ 9 NONAME ; DPrimaryMediaBase::DoEndInCritical(void)
	DoInCritical__17DPrimaryMediaBase @ 10 NONAME ; DPrimaryMediaBase::DoInCritical(void)
	EndInCritical__12DMediaDriver @ 11 NONAME ; DMediaDriver::EndInCritical(void)
	ForceMediaChange__17DPrimaryMediaBasei @ 12 NONAME ; DPrimaryMediaBase::ForceMediaChange(int)
	InCritical__12DMediaDriver @ 13 NONAME ; DMediaDriver::InCritical(void)
	InitiatePowerUp__17DPrimaryMediaBase @ 14 NONAME ; DPrimaryMediaBase::InitiatePowerUp(void)
	NotifyEmergencyPowerDown__17DPrimaryMediaBase @ 15 NONAME ; DPrimaryMediaBase::NotifyEmergencyPowerDown(void)
	NotifyMediaChange__17DPrimaryMediaBase @ 16 NONAME ; DPrimaryMediaBase::NotifyMediaChange(void)
	NotifyMediaPresent__17DPrimaryMediaBase @ 17 NONAME ; DPrimaryMediaBase::NotifyMediaPresent(void)
	NotifyPowerDown__17DPrimaryMediaBase @ 18 NONAME ; DPrimaryMediaBase::NotifyPowerDown(void)
	NotifyPsuFault__17DPrimaryMediaBasei @ 19 NONAME ; DPrimaryMediaBase::NotifyPsuFault(int)
	OpenMediaDriverComplete__12DMediaDriveri @ 20 NONAME ; DMediaDriver::OpenMediaDriverComplete(int)
	PartitionInfoComplete__12DMediaDriveri @ 21 NONAME ; DMediaDriver::PartitionInfoComplete(int)
	PowerUpComplete__17DPrimaryMediaBasei @ 22 NONAME ; DPrimaryMediaBase::PowerUpComplete(int)
	QuickCheckStatus__17DPrimaryMediaBase @ 23 NONAME ; DPrimaryMediaBase::QuickCheckStatus(void)
	ReadRemote__14TLocDrvRequestP5TDes8i @ 24 NONAME ; TLocDrvRequest::ReadRemote(TDes8 *, int)
	Request__17DPrimaryMediaBaseR14TLocDrvRequest @ 25 NONAME ; DPrimaryMediaBase::Request(TLocDrvRequest &)
	SetCurrentConsumption__12DMediaDriveri @ 26 NONAME ; DMediaDriver::SetCurrentConsumption(int)
	SetTotalSizeInBytes__12DMediaDriverxP7TLocDrv @ 27 NONAME ; DMediaDriver::SetTotalSizeInBytes(long long, TLocDrv *)
	TotalSizeInBytes__12DMediaDriver @ 28 NONAME ; DMediaDriver::TotalSizeInBytes(void)
	WriteRemote__14TLocDrvRequestPC6TDesC8i @ 29 NONAME ; TLocDrvRequest::WriteRemote(TDesC8 const *, int)
	"_._12DMediaDriver" @ 30 NONAME ; DMediaDriver::~DMediaDriver(void)
	CheckAndAdjustForPartition__14TLocDrvRequest @ 31 NONAME ; TLocDrvRequest::CheckAndAdjustForPartition(void)
	RegisterMediaDevice__6LocDrv12TMediaDeviceiPCiP17DPrimaryMediaBaseiRC6TDesC8 @ 32 NONAME ; LocDrv::RegisterMediaDevice(TMediaDevice, int, int const *, DPrimaryMediaBase *, int, TDesC8 const &)
	__17DPrimaryMediaBase @ 33 NONAME ; DPrimaryMediaBase::DPrimaryMediaBase(void)
	Disconnect__12DMediaDriverP11DLocalDriveP14TThreadMessage @ 34 NONAME ; DMediaDriver::Disconnect(DLocalDrive *, TThreadMessage *)
	Create__6DMedia12TMediaDeviceii @ 35 NONAME ; DMedia::Create(TMediaDevice, int, int)
	DoRequest__17DPrimaryMediaBaseR14TLocDrvRequest @ 36 NONAME ; DPrimaryMediaBase::DoRequest(TLocDrvRequest &)
	HandleMsg__17DPrimaryMediaBaseR14TLocDrvRequest @ 37 NONAME ; DPrimaryMediaBase::HandleMsg(TLocDrvRequest &)
	RunDeferred__17DPrimaryMediaBase @ 38 NONAME ; DPrimaryMediaBase::RunDeferred(void)
	DefaultDriveCaps__17DPrimaryMediaBaseR17TLocalDriveCapsV2 @ 39 NONAME ; DPrimaryMediaBase::DefaultDriveCaps(TLocalDriveCapsV2 &)
	RegisterPasswordStore__6LocDrvP14TPasswordStore @ 40 NONAME ; LocDrv::RegisterPasswordStore(TPasswordStore *)
	IsRemovableDevice__17DPrimaryMediaBaseRi @ 41 NONAME ; DPrimaryMediaBase::IsRemovableDevice(int &)
	PasswordStore__6LocDrv @ 42 NONAME R3UNUSED ; LocDrv::PasswordStore(void)
	ReadRemoteRaw__14TLocDrvRequestPvi @ 43 NONAME R3UNUSED ; TLocDrvRequest::ReadRemoteRaw(void *, int)
	WriteRemoteRaw__14TLocDrvRequestPCvi @ 44 NONAME R3UNUSED ; TLocDrvRequest::WriteRemoteRaw(void const *, int)
	ReadRemote__14TLocDrvRequestPCvP5TDes8 @ 45 NONAME R3UNUSED ; TLocDrvRequest::ReadRemote(void const *, TDes8 *)
	RegisterPagingDevice__6LocDrvP17DPrimaryMediaBasePCiiUiiUi @ 46 NONAME ; LocDrv::RegisterPagingDevice(DPrimaryMediaBase *, int const *, int, unsigned int, int, unsigned int)
	WriteToPageHandler__14TLocDrvRequestPCvii @ 47 NONAME ; TLocDrvRequest::WriteToPageHandler(void const *, int, int)
	NextLBA__22TPartitionTableScanner @ 48 NONAME R3UNUSED ; TPartitionTableScanner::NextLBA(void)
	NumberOfPartitionsFound__C22TPartitionTableScanner @ 49 NONAME R3UNUSED ; TPartitionTableScanner::NumberOfPartitionsFound(void) const
	Set__22TPartitionTableScannerPUcP15TPartitionEntryix @ 50 NONAME ; TPartitionTableScanner::Set(unsigned char *, TPartitionEntry *, int, long long)
	GetNextPhysicalAddress__14TLocDrvRequestRUlRi @ 51 NONAME R3UNUSED ; TLocDrvRequest::GetNextPhysicalAddress(unsigned long &, int &)
	RegisterDmaDevice__6LocDrvP17DPrimaryMediaBaseiii @ 52 NONAME ; LocDrv::RegisterDmaDevice(DPrimaryMediaBase *, int, int, int)
	ReadFromPageHandler__14TLocDrvRequestPvii @ 53 NONAME ; TLocDrvRequest::ReadFromPageHandler(void *, int, int)

